| Title: | Test Single Package Builder |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Lori Shepherd [aut] |
| Maintainer: | Lori Shepherd <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 0.99.119 |
| Built: | 2026-05-25 10:44:40 UTC |
| Source: | https://github.com/Bioconductor/spbtest3 |
A simple test function. show link[ape]{drop.tip} %>%
test() test2() test8(x)test() test2() test8(x)
A logical TRUE
test() # workflow and data experiment get 4800 sec (80 min) # software times out after 10 min (600 sec) # package guideline for software is 5 min (300 sec) Sys.sleep(1) test2() T <- "something" T # test a donttest me <- "lori" test8()test() # workflow and data experiment get 4800 sec (80 min) # software times out after 10 min (600 sec) # package guideline for software is 5 min (300 sec) Sys.sleep(1) test2() T <- "something" T # test a donttest me <- "lori" test8()
A simple test function.
whoami()whoami()
The name of the package as a character string
myfunction <- function(){ iam <- FALSE } myfunction() whoami() ## Not run: # test a dontrun a = 1 ## End(Not run)myfunction <- function(){ iam <- FALSE } myfunction() whoami() ## Not run: # test a dontrun a = 1 ## End(Not run)
A simple test function2.
whoami()whoami()
The name of the package as a character string